# Termos de Serviço

O Laboratório Hacker da Câmara dos Deputados apresenta os Termos de Uso do Portal e-Democracia, com condições gerais aplicáveis à utilização do site e de suas ferramentas associadas - a exemplo do Wikilegis, Expressão e Audiências Interativas -, além dos demais mecanismos de participação a serem oferecidos, inclusive aqueles que se encontrarem em fase *beta* ou em testes.

Neste documento estão descritas as responsabilidades e políticas referentes ao processo participativo, de modo que a aceitação plena e integral destes Termos de Uso é condição indispensável para a utilização do portal e das mencionadas ferramentas. 

O Usuário deverá ler, certificar-se de haver entendido e aceitar todas as condições aqui estabelecidas antes de seu cadastro no Portal e-Democracia.
Ressalte-se que a violação destes Termos de Uso poderá ensejar o cancelamento de contas, inabilitação para utilização dos serviços do portal e-Democracia, podendo também serem removidos ou descartados conteúdos postados em desacordo com as normas aqui descritas, o que reforça a necessidade de leitura e compreensão das mesmas.


## 1. Objeto

1. O Portal e-Democracia oferece ao usuário uma variedade de recursos online para subsidiar a participação da sociedade no processo legislativo, de modo a facilitar a interação dos cidadãos com os deputados federais.
2. Todos os esforços serão envidados para assegurar que os serviços funcionem da melhor maneira possível, cientificado o usuário de que falhas poderão ocorrer, dada a interdependência de fatores técnicos e operacionais.

## 2. Cadastro e Segurança

1. Para fins de cadastro no portal, é necessário o preenchimento de todos os campos exigidos, utilizando-se informações precisas e verdadeiras, que deverão ser mantidas atualizadas pelo usuário.
 2. Os usuários garantem e respondem, em qualquer caso, pela veracidade, exatidão e autenticidade dos dados pessoais cadastrados, não se responsabilizando o portal e-Democracia pela correção de tais dados.
3. Para fins de confirmação dos dados informados pelo usuário, exigir-se-á validação por meio de e-mail de confirmação, reservando-se o e-Democracia do direito de utilizar todos os meios legalmente válidos para identificar seus usuários, podendo, inclusive, solicitar dados adicionais e documentos que julgar pertinentes.
4. As credenciais de acesso ao portal e-Democracia constituem dados de exclusivo conhecimento do usuário, que se compromete a não os ceder a terceiros, sob pena de integral responsabilidade pelo seu uso indevido.
5. O usuário compromete-se a notificar imediatamente o acesso ou qualquer uso não autorizado de seu perfil na plataforma.
6. Por ocasião do cadastro no site, não serão admitidos nomes de usuários que possam levar os demais usuários a acreditar que esse fala em nome de outra pessoa ou organização, bem como utilização de nomes pré-existentes na plataforma.
7. Não poderão ser utilizados como nome de usuário termos que veiculem ofensas ou linguagem inapropriada, casos passíveis de ensejar o bloqueio, desativação ou remoção da conta sem aviso prévio, mas com posterior notificação e exposição de motivos.
8.  O cadastro ou disponibilização de conteúdo no portal e-Democracia não geram, por si só, direito suporte técnico, não cabendo qualquer tipo de reparação, compensação ou outra obrigação em caso de cancelamento, suspensão, perda, indisponibilidade ou outra situação adversa que afete o acesso, os dados ou o conteúdo do usuário.
8.  O portal e-Democracia poderá especificar prazo máximo de inatividade das contas para fins de desativamento de perfis em desuso, desde que previamente notificados os usuários. Neste caso, os e-mails excluídos poderão ser novamente utilizados para criação futura de um novo perfil pelo usuário.

## 3. Privacidade da Informação

1.  O e-Democracia tomará todas as medidas possíveis para manter a confidencialidade e a segurança dos dados pessoais informados na plataforma, não respondendo, contudo, por prejuízos que possam derivar da violação dessas medidas por parte de terceiros que utilizem redes públicas ou a internet para subverter os sistemas de segurança.
2.  O e-Democracia poderá disponibilizar dados cadastrais do usuário apenas para fins científicos à entidades e pesquisadores de alta credibilidade no meio acadêmico, à vista de termo de responsabilidade, com cláusula de sigilo da informação, e desde que sua utilização beneficie o aperfeiçoamento dos processos participativos do portal.
3. A utilização de cookies é necessária para o provimento de uma experiência participativa estruturada e personalizada aos usuários, bem como para compilação de dados agregados sobre o tráfego no site, além do mapeamento do fluxo de interações e engajamento participativo no portal. Caso o usuário não concorde com essa prática, poderá desabilitar a opção cookies diretamente em seu navegador de internet, ficando ciente de que tal procedimento poderá comprometer o pleno funcionamento.

## 4. Violação no Sistema ou Base de Dados

1. Não é permitida a utilização de nenhum dispositivo, software, ou outro recurso que venha a interferir nas atividades e operações do Portal e-Democracia. Qualquer intromissão, tentativa de, ou atividade que viole ou contrarie as leis de direito de propriedade intelectual e/ou as proibições estipuladas nestes Termos de Uso, tornarão o responsável passível das ações legais pertinentes, bem como das sanções aqui previstas, sendo ainda responsável pelas indenizações por eventuais danos causados.

## 5. Sanções

1. Sem prejuízo de outras medidas, inclusive ações judiciais, o e-Democracia poderá advertir, suspender ou cancelar, temporária ou definitivamente, a qualquer tempo, a conta do usuário que infringir as previsões destes Termos de Uso, especialmente no caso de postagens ou comportamentos que tenham causado danos a terceiros ou ao próprio e-Democracia ou que tenham ostentem potencialidade para tal.
2. As mesmas sanções poderão ser aplicadas no caso de fornecimento de informações inverídicas, fraudulentas ou de difícil confirmação em postagens ou no cadastro do usuário.

## 6. Inexistência de Vínculo

1. O cadastro no portal e-Democracia e a participação do usuário no portal não geram nenhum tipo de relação contratual ou mandatária, tampouco vínculo trabalhista ou societário, nem de parceria ou de caráter associativo.
2. O e-Democracia não garante a veracidade das postagens veiculadas nas ferramentas que disponibiliza, bem como não se responsabiliza pelo teor da comunicação realizada pelos usuários entre si, por meio de mensagens ou quaisquer outros procedimentos.
3. O e-Democracia não se responsabiliza por qualquer dano, prejuízo ou perda no equipamento de terceiros derivados de mau uso do usuário ou causados por falhas no sistema, no servidor ou na internet, decorrentes de atos ou conduta alheios.
4. O e-Democracia não se responsabilizará por transtornos decorrentes da exposição do usuário à rede mundial de computadores, tais como infecção por softwares maliciosos – malwares – ou perda de dados, sejam eles imagens, textos, áudios ou quaisquer outros tipos de arquivo.
5. Eventualmente o sistema poderá não estar disponível por motivos técnicos, evento fortuito ou causas de força maior, situações em que o e-Democracia não se responsabiliza por transtornos, contratempos ou prejuízos decorrentes da impossibilidade de acesso ao portal.


## 7. Propriedade Intelectual

1. As logomarcas, nome de domínio, conteúdos das telas, estrutura dos programas, bancos de dados, redes e arquivos que permitem ao usuário acesso e utilização de sua conta são de propriedade exclusiva do e-Democracia.
2. O e-Democracia poderá ceder, no todo ou em parte, a tecnologia desenvolvida e utilizada no portal, para fins de colaboração com instituições que partilhem dos mesmos interesses em participação popular, cidadania e transparência nos dados públicos.
3. Poderão ser disponibilizados na plataforma do portal e-Democracia endereços eletrônicos de outros sites ou portais parceiros, o que não significa que esses sejam de propriedade ou operados pelo e-Democracia, a quem não cabe responsabilização pelo acesso aos mesmos.
4. e-Democracia não será responsável por conteúdos, práticas e serviços ofertados em sites ou portais referenciados na plataforma por ele, por usuários ou por terceiros. 


## 8. Postagens nos Fóruns

1. O conteúdo postado no portal é de inteira responsabilidade do usuário autor, não recaindo sobre o e-Democracia qualquer responsabilidade decorrente desse conteúdo.
2. O usuário deverá atentar para o escopo e objetivo do debate em que deseja contribuir, mantendo-se adstrito ao assunto da discussão e acatando as definições adotadas pelo e-Democracia.
3. O usuário do portal e-Democracia se compromete a tratar com cordialidade e respeito os demais usuários, deixando claro quando não tiver certeza de alguma informação que houver postado, além de procurar sugerir links apenas para conteúdos que guardarem relação direta com o assunto em questão.
3. Não serão aceitas postagens que contenham vocabulário ofensivo ou desrespeitoso, tampouco aquelas com linguagem excessiva que veicule ofensas, calúnias, injúrias e difamações.
4. As postagens deverão atentar para o devido respeito à privacidade de terceiros, não podendo revestir-se de caráter ameaçador, vulgar, obsceno, preconceituoso, racista ou de alguma forma censuráveis, sob as penas da Lei e destes Termos de Uso.
5. O usuário do portal deverá cientificar-se de que a sua publicação está de acordo com a legislação em vigor no que se refere à proteção de direitos autorais de terceiros, propriedade material e imaterial, abstendo-se de compartilhar material que possa ser considerado ilegal ou que incite ou favoreça práticas em desacordo com a legislação.
6. Toda postagem veicula por meio do Portal e-Democracia é considerada pública, sendo vedado o anonimato, nos termos da lei.
7. A remoção ou edição de comentários por iniciativa de seu próprio autor é facultada de acordo com as opções disponíveis na ferramenta de gestão de conteúdo, quando houver.
8. Sempre que possível, práticas como o spam ou abuso em comentários serão preventivamente combatidas através do bloqueio de palavras e expressões, bem como serão excluídas as mensagens que veiculem esse tipo de conteúdo, outorgando-se aos usuários a possibilidade de sinalização de postagens que violem essa regra.
9. Tentativas de burla do sistema de moderação ou a reiterada infringência das regras sobre postagens constantes destes Termos de Uso ensejarão o desativamento da conta do usuário, com inabilitação do respectivo e-mail para criação de novas contas no portal.
10. A reinclusão de material que já tenha sido previamente excluído por meio de moderação de conteúdo constitui falta grave a ensejar o desativamento da conta do usuário, com inabilitação do respectivo e-mail para criação de novas contas no portal


## 9. Vedações

1. É vedado ao usuário transmitir, exibir, enviar, ou de qualquer forma disponibilizar qualquer conteúdo ilegal, ofensivo à honra, ameaçador, vulgar, obsceno, preconceituoso, racista ou de qualquer forma censurável ou que coloque em risco os direitos de terceiros, em especial os direitos de privacidade.
3. É vedado ao usuário assumir sem autorização a "personalidade" de outra pessoa, física ou jurídica, utilizando contas de terceiros ou o seu próprio perfil no portal e-Democracia, sob pena de responsabilização civil e criminal, nos termos da lei.
4. É vedado ao usuário forjar cabeçalhos, ou de qualquer outra forma manipular a identidade visual do portal ou de conteúdos nele transmitidos de forma a dissimular a sua origem ou autoria.
5. É vedado ao usuário disponibilizar conteúdo sobre o qual não tenha domínio ou direito, em especial aqueles que violem marca, patente, segredo de negócio ou direito autoral sob pena de responsabilização civil e criminal, nos termos da lei.
6. É vedado ao usuário disponibilizar qualquer tipo de propaganda, material promocional e mensagens não solicitadas ("junk mail" ou "spam"), assim como correntes ou esquemas de pirâmide.
7. É vedado ao usuário disponibilizar conteúdo que contenha vírus ou qualquer outro código, arquivo ou programa de computador com o propósito de interromper, destruir ou limitar a funcionalidade de qualquer outro software, hardware ou equipamento de telecomunicações.
9. É vedado ao usuário interferir ou interromper os serviços, as redes ou os servidores conectados ao portal, assim como obter ou tentar obter acesso não autorizado a outros sistemas, bancos de dados ou redes de computadores conectados ao portal sob pena de responsabilização civil e criminal, nos termos da lei;
10. É vedado ao usuário interromper o fluxo normal de um diálogo, interferir na utilização e aproveitamento dos serviços por outros usuários, ou de qualquer outra forma afetar a capacidade de outros usuários utilizarem os serviços do Portal.
12. É vedado ao usuário a promoção de propaganda política no portal, assim considerados atos como pedir votos, mencionar número de candidato ou de partido político ou expressar qualquer outra manifestação que possa ser caracterizada como infração às normas atinentes à matéria.


## 10. Licença de Uso do Conteúdo

1.   Todo o conteúdo textual originalmente postado no Portal e-Democracia submete-se a licença Creative Commons, ficando livremente disponível para leitura, uso, redistribuição ou modificação, salvo quando explicitamente mencionado tratar-se de citação de obra de terceiros, desde que adequadamente indicada nos termos da pela Lei 9.610/98.

## 11. Reportação de Violações

1.  O usuário poderá reportar ao e-Democracia qualquer conteúdo que entenda violar direito seu ou a postagem, artigo, notícia, comentário ou outro do Portal e-Democracia viole algum direito seu ou a legislação aplicável, utilizando, para tanto, os canais de comunicação disponibilizados no site.
2.  Para fins de comunicação de violação, o usuário deverá informar o título da página específica em que se encontra o conteúdo questionado, o endereço (URL) da página em que se encontra, a natureza da eventual violação, o trecho específico do texto em que ocorre a potencial infração, a providência que deseja ser tomada, bem como as suas informações de contato, preferencialmente e-mail.
3.  De posse dessas informações, o e-Democracia analisará a questão a fim de resolvê-la o mais brevemente possível. Caso a demanda não se encontre suficientemente instruída – informações incompletas ou detalhamento insuficiente - o e-Democracia poderá entrará em contato com o solicitante a fim de solicitar sua complementação das informações.
4.  Comunicações de violações e solicitações de providências enviadas sem identificação completa do requerente, descrição detalhada ou justificada da violação não serão atendidas.

## 12. Práticas de Uso e Armazenamento

1.  Cabe ao e-Democracia estabelecer, a seu exclusivo critério e cientificados os usuários, o número máximo de dias em que mensagens de e-mail, postagens em fóruns ou outros conteúdos disponibilizados serão armazenados no Portal, assim como o número máximo de mensagens que podem ser enviadas ou recebidas por uma determinada conta, além do tamanho máximo de uma mensagem a ser enviada ou recebida por uma determinada conta, incluindo o espaço máximo em disco no servidor disponibilizado para tais conteúdos.
2.  O e-Democracia não assume qualquer responsabilidade ou obrigação pela exclusão ou falha no armazenamento de mensagens e outras comunicações ou conteúdos mantidos e transmitido através do site.
3.  O e-Democracia reserva-se do direito de modificar estas práticas gerais e limites a qualquer tempo, a seu exclusivo critério, cientificados os usuários cadastrados.

## 13. Modificações nos Termos de Uso

1.  O e-Democracia poderá alterar, a qualquer tempo, estes Termos de Uso, visando seu aprimoramento e melhoria dos serviços prestados. Os novos Termos de Uso entrarão em vigor a partir de sua publicação no site, notificados os usuários cadastrados. A não exclusão da conta pelo usuário notificado implicará aceitação tácita dos novos Termos de Uso.

## 14. Foro e Legislação Aplicável

1.    Todos os itens deste Termo de Uso estão regidos pelas leis vigentes na República Federativa do Brasil. Para todos os assuntos referentes à sua interpretação e cumprimento, as partes se submeterão ao foro de Brasília.
2.    O e-Democracia submete-se a legislação em vigor, em especial no que se refere às leis eleitorais, não fazendo referência ou menção de apreço ou desapreço a partidos, candidatos ou ocupantes de cargos políticos.
